#
# spec file for package gpxsee
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# See also http://en.opensuse.org/openSUSE:Specfile_guidelines

Name:           gpxsee
Version:        5.10
Release:        lp150.1.1
Summary:        GPS log files visualizing and analyzing tool
License:        GPL-3.0
Group:          Productivity/Graphics/Visualization
Url:            http://www.gpxsee.org
Source0:        GPXSee-%{version}.tar.gz

BuildRequires:  gcc-c++
BuildRequires:  make
%if 0%{?fedora_version}
%if 0%{?fedora_version} >= 24
BuildRequires:  qt5-qtbase
BuildRequires:  qt5-qtbase-gui
BuildRequires:  qt5-qtbase-devel
BuildRequires:  qt5-linguist
%else
BuildRequires:  libqt4-devel
%endif
%endif
%if 0%{?suse_version}
BuildRequires:  libQt5Core-devel
BuildRequires:  libQt5Gui-devel
BuildRequires:  libQt5Widgets-devel
BuildRequires:  libQt5Network-devel
BuildRequires:  libQt5PrintSupport-devel
BuildRequires:  libQt5OpenGL-devel
BuildRequires:  libqt5-linguist
%endif
%if 0%{?rhel_version} || 0%{?centos_version}
BuildRequires:  libqt4-devel
%endif


%description
GPXSee is a Qt-based tool for visualizing and analyzing GPX, TCX, FIT, KML,
IGC, NMEA, OziExplorer files and Garmin CSV files.

%prep
%setup -q -n GPXSee-%{version}

%build
%if 0%{?fedora_version} >= 24
lrelease-qt5 gpxsee.pro
%{qmake_qt5} gpxsee.pro
%else
%if 0%{?suse_version}
lrelease-qt5 gpxsee.pro
qmake-qt5 gpxsee.pro
%else
lrelease-qt4 gpxsee.pro
qmake-qt4 gpxsee.pro
%endif
%endif
make %{?_smp_mflags}

%install
install -d 755 %{buildroot}/%{_bindir}
install -d 755 %{buildroot}/%{_datadir}/applications
install -d 755 %{buildroot}/%{_datadir}/pixmaps
install -d 755 %{buildroot}/%{_datadir}/mime/packages
install -d 755 %{buildroot}/%{_datadir}/%{name}
install -d 755 %{buildroot}/%{_datadir}/%{name}/maps
install -d 755 %{buildroot}/%{_datadir}/%{name}/csv
install -d 755 %{buildroot}/%{_datadir}/%{name}/translations
install -m 755 GPXSee %{buildroot}/%{_bindir}/%{name}
install -m 644 pkg/maps/* %{buildroot}/%{_datadir}/%{name}/maps
install -m 644 pkg/csv/* %{buildroot}/%{_datadir}/%{name}/csv
install -m 644 lang/*.qm %{buildroot}/%{_datadir}/%{name}/translations
install -m 644 icons/gpxsee.png %{buildroot}/%{_datadir}/pixmaps/%{name}.png
install -m 644 pkg/gpxsee.desktop %{buildroot}/%{_datadir}/applications/%{name}.desktop
install -m 644 pkg/gpxsee.xml %{buildroot}/%{_datadir}/mime/packages/%{name}.xml

%post
if [ -x /usr/bin/update-mime-database ]; then
	/usr/bin/update-mime-database %{_datadir}/mime &> /dev/null || :
fi
if [ -x /usr/bin/update-desktop-database ]; then
	/usr/bin/update-desktop-database > /dev/null || :
fi

%postun
if [ -x /usr/bin/update-mime-database ]; then
	/usr/bin/update-mime-database %{_datadir}/mime &> /dev/null || :
fi
if [ -x /usr/bin/update-desktop-database ]; then
	/usr/bin/update-desktop-database > /dev/null || :
fi

%files
%defattr(-,root,root)
%dir %{_datadir}/gpxsee
%{_bindir}/*
%{_datadir}/%{name}/*
%{_datadir}/applications/*
%{_datadir}/pixmaps/*
%{_datadir}/mime/packages/*

%changelog
* Wed May  9 2018 tumic@cbox.cz
- Update to version 5.10
  * Improved track loading performance.
  * Improved network/server error handling.
  * Added missing EST97 GCS/PCS.
  * Several minor bugfixes and improvements.
* Thu Apr 19 2018 tumic@cbox.cz
- Update to version 5.9
  * Fixed HTTP redirects handling.
  * Proper fix of the zoom changes/offset bugs (resolved only
    partialy in 5.8).
* Wed Apr 18 2018 tumic@cbox.cz
- Update to version 5.8
  * Fixed the irritating map zoom changes on OSM maps switching and
    the 1px map center offset bug.
  * Added Polish translation.
* Tue Apr 17 2018 tumic@cbox.cz
- Update to version 5.7
  * Added OziExplorer data files (plt, rte, wpt) support.
* Sun Apr  8 2018 tumic@cbox.cz
- Update to version 5.6
  * Added WMS support.
  * Several minor bugfixes and improvements (mostly WMTS).
* Tue Mar 20 2018 tumic@cbox.cz
- Update to version 5.5
  * Fixed deadlocks caused by infinite HTTP timeout.
  * Several minor bugfixes.
* Sun Mar 11 2018 tumic@cbox.cz
- Update to version 5.4
  * Added pace info.
  * Added support for EPSG 21781 PCS (Swiss grid).
  * Added missing WMTS dimensions handling.
  * Fixed broken zoom rectangle computation.
  * Fixed swapped GeoTIFF LCC1 and LCC2 projection codes.
  * Fixed loading of WGS84 GeoTIFF images defined using
    the ellipsoid only.
  * Fixed broken (case-sensitive) WMTS parameters handling.
* Thu Mar  1 2018 tumic@cbox.cz
- Update to version 5.3
  * Added support for WMTS maps.
  * Fixed Lambert azimuthal equal area projection.
  * Improved scale computation on offline maps.
  * Added some more GCS/PCS definitions.
  * Fixed invalid memory access.
* Sat Feb 17 2018 tumic@cbox.cz
- Update to version 5.2
  * Fixed broken GeoTIFF (Web) Mercator projection.
  * Several minor bug fixes.
* Mon Feb 12 2018 tumic@cbox.cz
- Update to version 5.1
  * Fixed crash during static data initialization.
  * Added coordinates format setting.
  * Added nautical units setting.
* Sat Feb 10 2018 tumic@cbox.cz
- Update to version 5.0
  * Added support for GeoTIFF images.
  * Online map sources are now defined using XML files.
  * Added Finnish, French and Russian localization.
* Mon Jan  8 2018 tumic@cbox.cz
- Update to version 4.19
  * Fixed missing cached content cleanup causing huge draw areas
    (causing system memory exhaustion) issue.
* Sat Jan  6 2018 tumic@cbox.cz
- Update to version 4.18
  * Fixed broaken A records parsing in IGC files.
  * Added support for negative altitudes in IGC files.
* Sat Dec  9 2017 tumic@cbox.cz
- Update to version 4.17
  * Added support for Lambert Azimuthal Equal Area projections.
  * Added support for map viewing without GPS log files loaded.
  * Added slider/marker color setting.
  * Fixed scene centering issue.
  * Fixed offline map scale computation issue.
  * Fixed some corner case map drawing issues.
* Wed Oct 18 2017 tumic@cbox.cz
- Update to version 4.16
  * Fixed broken loading of KML files with folder elements outside
    document element.
  * Added support for KML files with multitracks.
  * Added support for Temperature, Cadence and Heartrate in KML
    files.
  * Added support for TCX multi-sport activities.
* Fri Oct  6 2017 tumic@cbox.cz
- Update to version 4.15
  * Fixed the 1px content offset on zoom/map change issue.
  * Improved graph slider info.
  * Graph items are now selecteble like path items (+ tool tips).
* Fri Sep 15 2017 tumic@cbox.cz
- Update to version 4.14
  * Fixed broken parsing of TCX files with heart rate data.
  * Fixed invalid memory access in NMEA parser.
  * Fixed broken units setting for cadence, heart rate and power
    graphs.
  * Added support for limiting the maximal zoom level of online map
    sources.
  * Added waypoints/POI size/color settings and map background
    color settings.
  * Adjusted the scale bar (text) size to the remaining content
    in print/PDF export output.
* Sun Sep  3 2017 tumic@cbox.cz
- Update to version 4.13
  * Added support for high-resolution printing.
* Thu Aug 24 2017 tumic@cbox.cz
- Update to version 4.12
  * Fixed broken LCC projection on southern hemisphere.
  * Added support for France I-IV and VICGRID/VICGRID94 projections.
  * Added map opacity (brightness) setting.
  * Added 4UMaps to map sources.
* Tue Aug 15 2017 tumic@cbox.cz
- Update to version 4.11
  * Fixed QT4 build.
* Tue Aug 15 2017 tumic@cbox.cz
- Update to version 4.10
  * Added support for OZF zoom levels.
  * Added support for maps with only 2 reference points.
  * Various map loading/displaying improvements.
* Tue Jul 11 2017 tumic@cbox.cz
- Update to version 4.9
  * Improved map switching (no more track resizing on map change).
  * Improved TARed Trekbuddy maps loading (now using TMI index
    files if available).
  * Optimized POI handling.
* Thu May 25 2017 tumic@cbox.cz
- Update to version 4.8
  * Added data filtering settings.
  * Fixed broken units handling in track info tooltips.
* Tue May  9 2017 tumic@cbox.cz
- Update to version 4.7
  * Fixed broken offline maps on southern hemisphere.
  * Fixed broken UTM zone setup on some offline maps.
  * Added support for OZF3 files.
  * Added support for Albers Equal-Area projection.
  * Added support for offline maps with projections defined as
    British, Irish and Swedish grid and NZTM2000.
* Tue May  2 2017 tumic@cbox.cz
- Update to version 4.6
  * Fixed broken PDF export/printing (broken map scale/waypoints
    size).
  * Improved path projection performance when an atlas is used.
* Sun Apr 23 2017 tumic@cbox.cz
- Update to version 4.5
  * Added support for "runtime" loading of offline maps.
  * Fixed atlas zoom fitting.
  * Fixed various minor offline map loading issues.
* Mon Apr 17 2017 tumic@cbox.cz
- Update to version 4.4
  * Added support for ozf2 image files.
  * Added full support for non-WGS84 datum based offline maps.
  * Added German localization.
* Wed Apr 12 2017 tumic@cbox.cz
- Update to version 4.3
  * Fixed missing cached content cleanup causing huge draw areas
    (causing memory exhaustion) issue.
  * Fixed map file defined datum not set for UTM maps issue.
* Thu Apr  6 2017 tumic@cbox.cz
- Update to version 4.2
  * Added digital zoom.
  * Fixed atlas map fitting algorithm.
  * Completed Swedish translation.
* Sun Apr  2 2017 tumic@cbox.cz
- Update to version 4.1
  * Added support for Lambert conformal conic projection.
* Sat Apr  1 2017 tumic@cbox.cz
- Update to version 4.0
  * Added support for offline maps.
  * Fixed zoom issues on touchpads.
* Mon Feb 13 2017 tumic@cbox.cz
- Update to version 3.9
  * Fixed broken POI radius computation.
  * Added moving time info.
  * Improved pause detection/handling.
* Tue Jan 24 2017 tumic@cbox.cz
- Update to version 3.8
  * Fixed graph info not redrawing issue.
  * Added Swedish localization.
* Mon Jan 23 2017 tumic@cbox.cz
- Update to version 3.7
  * Fixed tile downloading issues (multiple downloads, redirect
    loop).
  * Enabled free map scroll.
* Tue Dec 20 2016 tumic@cbox.cz
- Update to version 3.5
  * Fixed broken NMEA latitude parsing.
  * Added print/export options.
* Sat Dec 10 2016 tumic@cbox.cz
- Update to version 3.4
  * Fixed QT5 < 5.4 builds (Debian 8).
* Fri Dec  9 2016 tumic@cbox.cz
- Update to version 3.3
  * Added options dialog with basic appearance settings.
  * Added OpenGL support.
* Tue Nov 22 2016 tumic@cbox.cz
- Update to version 3.2
  * Added support for NMEA files.
  * Fixed path marker inaccuracy bug.
* Sat Nov 12 2016 tumic@cbox.cz
- Update to version 3.1
  * Added support for IGC files.
  * Fixed zoom level computation bugs.
* Mon Nov  7 2016 tumic@cbox.cz
- Update to version 3.0
  * Added support for TCX, KML and FIT files.
  * Added cadence and power graphs.
  * Improved outlier detection (now also applies to track points).
  * GUI polishing.
  * Improved print output.
* Sun Oct 16 2016 tumic@cbox.cz
- Update to version 2.20
  * Added support for drag&drop.
  * Fixed graph line distortion in PDF output.
  * Fixed POI loading performance issue.
  * GUI polishing.
* Wed Sep 28 2016 tumic@cbox.cz
- Update to version 2.19
  * Added time-based graphs.
  * Added track/graph highlighting (on track hover).
  * Added support for proxy connections (using the system-defined
    proxy).
  * Fixed PDF output in QT4 builds.
* Wed Aug 31 2016 tumic@cbox.cz
- Update to version 2.18
  * Added support for GPX routes.
  * Added various data display options.
  * Improved performance.
* Wed Aug  3 2016 tumic@cbox.cz
- Update to version 2.17
  * Added waypoint/track info tooltips.
  * Improved POI handling.
* Thu Jun 16 2016 tumic@cbox.cz
- Update to version 2.16
  * Fixed infinite download loop on HTTP redirects (and broken
    images).
  * Fixed handling of GPX files with inconsistent track point
    entries.
  * Added support for temperature graphs.
* Sat May 28 2016 tumic@cbox.cz
- Update to version 2.14
  * Added print support.
  * Many fixes & improvements in PDF export (e.g. map support).
* Tue May  3 2016 tumic@cbox.cz
- Update to version 2.13
  * Fixed broken opening of non-ASCII named files as program
    arguments.
  * File info in window title.
  * Persistent program settings.
* Thu Apr 14 2016 tumic@cbox.cz
- Update to version 2.12
  * Added fullscreen mode.
  * Polished GUI.
* Sat Apr  2 2016 tumic@cbox.cz
- Update to version 2.11
  * Added "clear tile cache" option.
  * Lots of minor bug fixes and enhancements.
* Fri Mar 25 2016 tumic@cbox.cz
- Update to version 2.10
  * Added heart rate graphs.
  * Polished GUI.
  * Redesigned map/POI data sources handling.
  * Lots of minor bug fixes and enhancements.
* Sun Mar 20 2016 tumic@cbox.cz
- Update to version 2.9
  * Added support for displaying waypoints.
  * Minor bug fixes and enhancements.
* Sun Mar  6 2016 tumic@cbox.cz
- Update to version 2.8
  * Improved POI files control.
  * Minor bug fixes and enhancements.
* Sat Feb 13 2016 tumic@cbox.cz
- Update to version 2.7
  * Added default map sources (OSM, Thunderforest).
  * Added support for POIs in GPX format.
  * Added support for GPX files with multiple tracks.
* Wed Feb  3 2016 tumic@cbox.cz
- Update to version 2.6
  * Added map scale info.
  * Improved PDF export.
* Sun Dec 20 2015 tumic@cbox.cz
- Update to version 2.5
  * Added support for imperial units.
  * Fixed track view resizing issues.
